
# parsetab.py
# This file is automatically generated. Do not edit.
# pylint: disable=W,C,R
_tabversion = '3.10'

_lr_method = 'LALR'

_lr_signature = 'GRAMMARRULE LPAREN RPARENRelevantData : DataLinesDataLines : DataLine\n                 | DataLines DataLineDataLine : LPAREN GRAMMARRULE RPAREN'
    
_lr_action_items = {'GRAMMARRULE':([3,],[5,]),'LPAREN':([0,1,4,6,7,],[3,-2,3,-3,-4,]),'RPAREN':([5,],[7,]),'$end':([1,2,4,6,7,],[-2,0,-1,-3,-4,]),}

_lr_action = {}
for _k, _v in _lr_action_items.items():
   for _x,_y in zip(_v[0],_v[1]):
      if not _x in _lr_action:  _lr_action[_x] = {}
      _lr_action[_x][_k] = _y
del _lr_action_items

_lr_goto_items = {'DataLine':([0,4,],[1,6,]),'DataLines':([0,],[4,]),'RelevantData':([0,],[2,]),}

_lr_goto = {}
for _k, _v in _lr_goto_items.items():
   for _x, _y in zip(_v[0], _v[1]):
       if not _x in _lr_goto: _lr_goto[_x] = {}
       _lr_goto[_x][_k] = _y
del _lr_goto_items
_lr_productions = [
  ("S' -> RelevantData","S'",1,None,None,None),
  ('RelevantData -> DataLines','RelevantData',1,'p_relevantdata','parsetabtolatex_yacc.py',15),
  ('DataLines -> DataLine','DataLines',1,'p_datalines','parsetabtolatex_yacc.py',19),
  ('DataLines -> DataLines DataLine','DataLines',2,'p_datalines','parsetabtolatex_yacc.py',20),
  ('DataLine -> LPAREN GRAMMARRULE RPAREN','DataLine',3,'p_dataline','parsetabtolatex_yacc.py',27),
]



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb  3 16:26:32 2019

@author: Maria Climent-Pommeret
"""

import parsetabtolatex.parsetabtolatex_yacc as myyacc


class ParseTabToLatex:
    """
    Parses a parsetab.py file generated by ply and creates a .tex file
    containing the extracted grammar formatted using the syntax LaTeX
    package.
    """

    def __init__(self, infile, outfile):
        self.infile = infile
        self.outfile = outfile

    def generate_latex(self):
        with open(self.infile, "r") as parsetab:
            data = parsetab.read()
            code = myyacc.parser.parse(data).rewrite()
            with open(self.outfile, "w") as texfile:
                texfile.write(code)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb  3 11:53:19 2019

@author: Maria Climent-Pommeret
"""

import ply.lex as lex


tokens = [
    "GRAMMARRULE",
    "LPAREN",
    "RPAREN",
    ]

states = [
    ("grammar", "exclusive"),
    ]

t_ignore = "\n"
t_ignore_COMMENT = r"\#.*"
t_ignore_TABVERSION = r"_tabversion.*"
t_ignore_LRMETHOD = r"_lr_method.*"
t_ignore_LRSIGNATURE = r"_lr_signature.*"
t_ignore_SPACES = r"\ +"
t_ignore_CODE = r"[A-Za-z_0-9\\n].*"
t_ignore_LRACTIONS = r"_lr_action.*"
t_ignore_LISTS = r"\[.*"
t_ignore_DEL = r"del.*"
t_ignore_LRGOTO = r"_lr_goto.*"
t_ignore_TEXT = r"[A-Za-z\|\\n]+"

def t_error(t):
    print("Illegal character in INITIAL state '%s'" % t.value[0])
    t.lexer.skip(1)

def t_begin_grammar(t):
    r"_lr_productions\ =\ \["
    t.lexer.push_state("grammar")

def t_grammar_end(t):
    r"\]"
    t.lexer.pop_state()

def t_grammar_error(t):
    print("Illegal character in GRAMMAR state '%s'" % t.value[0])
    t.lexer.skip(1)

t_grammar_ignore = "\n\r\t ,"
t_grammar_GRAMMARRULE = r"(\"|\')[A-Za-z][a-zA-Z0-9_\']*\ ->\ .+?(?=,)"
t_grammar_ignore_QUOTEDGARBAGE = r"(\"|\').+(\"|\')(?=,)"
t_grammar_ignore_NONE = "None"
t_grammar_ignore_NUMBER = r"[0-9]+"
t_grammar_LPAREN = r"\("
t_grammar_RPAREN = r"\)"
lexer = lex.lex()


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb  3 14:48:09 2019

@author: Maria Climent-Pommeret
"""

class Node:
    """
    Basic Node Class

    Takes into parameter either:
        - a list of children
        - a single child
    """

    def __init__(self, children=None):
        self.pretty = "Basic Node"
        if not children:
            self.children = []
        elif hasattr(children, "__len__"):
            self.children = children[:]
        else:
            self.children = [children]

    def __str__(self):
        return "Node"

    def __repr__(self):
        return self.pretty


class RelevantDataNode(Node):
    """
    A node that contains all grammar rules.
    """
    pretty = "Relevant Data"

    def rewrite(self):
        code = "\\documentclass{article}\n"
        code += "\\usepackage{syntax}\n"
        code += "\\begin{document}\n"
        code += "\\begin{grammar}\n"

        previous_left = "S"
        for child in self.children:
            if child.left_member() == previous_left:
                code += child.rewrite_end()
            else:
                previous_left = child.left_member()
                code += child.rewrite_full()
        code += "\\end{grammar}\n\\end{document}\n"
        
        return code


class GrammarRuleNode(Node):
    """
    A node that contains a grammer rule.
    """
    pretty = "Grammar Rule"
    
    def left_member(self):
        return self.children.strip("'").strip('"').split(" ")[0]

    def rewrite_full(self):
        data = self.children.strip("'").strip('"').split(" ")
        if data[0].isupper() and data[0] != "S'":
            code = '\n\n    "%s" ::=' % data[0]
        else:
            code = '\n\n    <%s> ::= ' % data[0]

        for child in data[2:]:
            if child.isupper():
                code += ' "%s"' % child
            else:
                code += " <%s>" % child

        code += "\n"
        return code

    def rewrite_end(self):
        data = self.children.strip("'").strip('"').split(" ")
        code = "        \\alt"

        for child in data[2:]:
            if child.isupper():
                code += ' "%s"' % child
            else:
                code += " <%s>" % child

        code += "\n"
        return code


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb  3 13:01:33 2019

@author: Maria Climent-Pommeret
"""

import ply.yacc as yacc

from parsetabtolatex.parsetabtolatex_lex import tokens
import parsetabtolatex.parsetabtolatex_ast as AST

def p_relevantdata(p):
    """RelevantData : DataLines"""
    p[0] = AST.RelevantDataNode(p[1])

def p_datalines(p):
    """DataLines : DataLine
                 | DataLines DataLine"""
    if len(p) == 2:
        p[0] = [p[1]]
    else:
        p[0] = p[1] + [p[2]]

def p_dataline(p):
    """DataLine : LPAREN GRAMMARRULE RPAREN"""
    p[0] = AST.GrammarRuleNode(p[2])

def p_error(p):
    """
    Error handling.
    """
    if p:
        print("Syntax error at token ", p)
        parser.errok()
    else:
        print("Syntax error at EOF")

parser = yacc.yacc()


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Feb  2 21:17:43 2019

@author: Maria Climent-Pommeret
"""
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="parsetabtolatex",
    version="0.0.3",
    author="Maria Climent-Pommeret",
    author_email="maria@climent-pommeret.red",
    description="A parsetab.py parser that generates .tex file",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.climent-pommeret.red/Chopopope/parsetabtolatex/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Science/Research",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords="ply grammar LaTeX parser",
    install_requires=[
            "ply",
    ],
    python_requires='>=3.5',
)
